==> mule-module-policies-4.4.0-20220919-sources.jar: com/mulesoft/mule/runtime/gw/policies/factory/PolicyFactoryTemplate.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright law. All use of this software is subject to
 * MuleSoft's Master Subscription Agreement (or other Terms of Service) separately entered into between you and MuleSoft. If such an
 * agreement is not in place, you may not use the software.
 */
package com.mulesoft.mule.runtime.gw.policies.factory;

import com.mulesoft.mule.runtime.gw.model.PolicyConfiguration;
import com.mulesoft.mule.runtime.gw.model.PolicyDefinition;
import com.mulesoft.mule.runtime.gw.model.PolicySpecification;
import com.mulesoft.mule.runtime.gw.policies.template.PolicyTemplate;
import com.mulesoft.mule.runtime.gw.policies.template.provider.PolicyTemplateProvider;
import com.mulesoft.mule.runtime.gw.policies.template.resolver.PolicyTemplateResolver;

import java.util.HashMap;
import java.util.Map;

public abstract class PolicyFactoryTemplate implements PolicyFactory {

  private static final String IDENTITY_MANAGEMENT_TOKEN_URL = "identityManagementTokenUrl";
  private static final String IDENTITY_MANAGEMENT_CLIENT_ID = "identityManagementClientId";
  private static final String IDENTITY_MANAGEMENT_CLIENT_SECRET = "identityManagementClientSecret";

  private PolicyTemplateResolver templateResolver;
  private PolicyTemplateProvider templateProvider;

  public PolicyFactoryTemplate(PolicyTemplateResolver templateResolver,
                               PolicyTemplateProvider templateProvider) {
    this.templateResolver = templateResolver;
    this.templateProvider = templateProvider;
  }

  protected PolicyTemplate getPolicyTemplate(PolicyDefinition policyDefinition) {
    return templateProvider.provide(policyDefinition.getTemplateKey());
  }

  protected String resolveTemplate(PolicyTemplate policyTemplate, Map<String, Object> configurationData) {
    return templateResolver.resolve(policyTemplate, configurationData);
  }

  protected PolicyDefinition evaluatePolicyIdentityManagement(PolicyDefinition policyDefinition, PolicyTemplate policyTemplate) {
    if (shouldRemoveIdentityManagementProperty(policyDefinition.getConfigurationData().getConfiguration(),
                                               policyTemplate.getPolicySpecification())) {
      return getPolicyDefinitionWithoutIdentityManagement(policyDefinition);
    }
    return policyDefinition;
  }

  private boolean shouldRemoveIdentityManagementProperty(Map<String, Object> policyDefinitionConfiguration,
                                                         PolicySpecification policySpecification) {
    return policySpecification.isValid()
        && !policySpecification.getIdentityManagement().isPresent()
        && hasIdentityManagementProperty(policyDefinitionConfiguration);
  }

  private boolean hasIdentityManagementProperty(Map<String, Object> policyDefinitionConfiguration) {
    return policyDefinitionConfiguration.get(IDENTITY_MANAGEMENT_TOKEN_URL) != null
        || policyDefinitionConfiguration.get(IDENTITY_MANAGEMENT_CLIENT_ID) != null
        || policyDefinitionConfiguration.get(IDENTITY_MANAGEMENT_CLIENT_SECRET) != null;
  }

  private PolicyDefinition getPolicyDefinitionWithoutIdentityManagement(PolicyDefinition policyDefinition) {
    Map<String, Object> policyDefinitionConfiguration = new HashMap<>();
    policyDefinition.getConfigurationData().getConfiguration().forEach((configKey, configValue) -> {
      if (fieldNameDoesNotMatchIdentityManagement(configKey)) {
        policyDefinitionConfiguration.putIfAbsent(configKey, configValue);
      }
    });
    return new PolicyDefinition(policyDefinition.getId(), policyDefinition.getTemplateKey(), policyDefinition.getApiKeys(),
                                policyDefinition.getHttpResourcePointcuts(), policyDefinition.getOrder(),
                                new PolicyConfiguration(policyDefinitionConfiguration));
  }

  private boolean fieldNameDoesNotMatchIdentityManagement(String configKey) {
    return !(configKey.equals(IDENTITY_MANAGEMENT_TOKEN_URL) || configKey.equals(IDENTITY_MANAGEMENT_CLIENT_ID)
        || configKey.equals(IDENTITY_MANAGEMENT_CLIENT_SECRET));
  }

}

==> mule-module-policies-4.5.0-20220622-sources.jar: com/mulesoft/mule/runtime/gw/policies/factory/PolicyFactoryTemplate.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright law. All use of this software is subject to
 * MuleSoft's Master Subscription Agreement (or other Terms of Service) separately entered into between you and MuleSoft. If such an
 * agreement is not in place, you may not use the software.
 */
package com.mulesoft.mule.runtime.gw.policies.factory;

import com.mulesoft.mule.runtime.gw.model.PolicyDefinition;
import com.mulesoft.mule.runtime.gw.model.PolicySpecification;
import com.mulesoft.mule.runtime.gw.policies.PolicyDefinitionBuilder;
import com.mulesoft.mule.runtime.gw.policies.template.PolicyTemplate;
import com.mulesoft.mule.runtime.gw.policies.template.provider.PolicyTemplateProvider;
import com.mulesoft.mule.runtime.gw.policies.template.resolver.PolicyTemplateResolver;

import java.util.Map;

public abstract class PolicyFactoryTemplate implements PolicyFactory {

  private PolicyTemplateResolver templateResolver;
  private PolicyTemplateProvider templateProvider;

  public PolicyFactoryTemplate(PolicyTemplateResolver templateResolver,
                               PolicyTemplateProvider templateProvider) {
    this.templateResolver = templateResolver;
    this.templateProvider = templateProvider;
  }

  protected PolicyTemplate getPolicyTemplate(PolicyDefinition policyDefinition) {
    return templateProvider.provide(policyDefinition.getTemplateKey());
  }

  protected String resolveTemplate(PolicyTemplate policyTemplate, Map<String, Object> configurationData) {
    return templateResolver.resolve(policyTemplate, configurationData);
  }

  protected PolicyDefinition evaluatePolicyIdentityManagement(PolicyDefinition policyDefinition, PolicyTemplate policyTemplate) {
    if (shouldRemoveIdentityManagementProperty(policyDefinition, policyTemplate.getPolicySpecification())) {
      return getPolicyDefinitionWithoutIdentityManagement(policyDefinition);
    }
    return policyDefinition;
  }

  private boolean shouldRemoveIdentityManagementProperty(PolicyDefinition policyDefinition,
                                                         PolicySpecification policySpecification) {
    return policySpecification.isValid()
        && !policySpecification.getIdentityManagement().isPresent()
        && PolicyDefinitionBuilder.hasIdentityManagementProperties(policyDefinition);
  }

  private PolicyDefinition getPolicyDefinitionWithoutIdentityManagement(PolicyDefinition policyDefinition) {
    return new PolicyDefinitionBuilder(policyDefinition).noIdentityManagement().build();
  }

}
